import request from '@/config/axios'

// 装机拆机 VO
export interface DevRentVO {
  id: number | null // id
  devId: string // 设备编号
  patId: string // 患者编号
  patName: string // 患者名称
  rentTime: Date // 装机时间
  returnTime: Date // 拆机时间
  interference: number // 干扰数
  baseline: string // 基线粗
  detachment: string // 脱离
  remark: string // 备注
}

// 装机拆机 API
export const DevRentApi = {
  // 查询装机拆机分页
  getDevRentPage: async (params: any) => {
    return await request.get({ url: `/ecg/dev-rent/page`, params })
  },

  // 查询装机拆机详情
  getDevRent: async (id: number) => {
    return await request.get({ url: `/ecg/dev-rent/get?id=` + id })
  },

  // 新增装机拆机
  createDevRent: async (data: DevRentVO) => {
    return await request.post({ url: `/ecg/dev-rent/create`, data })
  },

  // 修改装机拆机
  updateDevRent: async (data: DevRentVO) => {
    return await request.put({ url: `/ecg/dev-rent/update`, data })
  },

  // 删除装机拆机
  deleteDevRent: async (id: number) => {
    return await request.delete({ url: `/ecg/dev-rent/delete?id=` + id })
  },

  // 导出装机拆机 Excel
  exportDevRent: async (params) => {
    return await request.download({ url: `/ecg/dev-rent/export-excel`, params })
  },

  // 获取患者设备最近的租赁
  getLatestRent: async (devId: string) => {
    return await request.get({ url: `/ecg/dev-rent/get-latest-rent?&dev-id=` + devId })
  }
}